package com.hfkj.service.order;

import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;
import com.hfkj.common.exception.ErrorCode;
import com.hfkj.common.exception.ErrorHelp;
import com.hfkj.common.exception.SysCode;
import com.hfkj.common.utils.DateUtil;
import com.hfkj.entity.*;
import com.hfkj.model.order.OrderModel;
import com.hfkj.service.coupon.BsOrderCouponNoService;
import com.hfkj.service.coupon.BsOrderCouponService;
import com.hfkj.service.coupon.channel.ChongQingCNPCCouponService;
import com.hfkj.service.coupon.channel.HuiLianTongCouponService;
import com.hfkj.service.coupon.channel.PcytCNPCCouponConfig;
import com.hfkj.service.coupon.channel.PetroConfig;
import com.hfkj.service.goods.BsOrderGoodsService;
import com.hfkj.service.goods.GoodsMsgService;
import com.hfkj.service.goods.GoodsVpdService;
import com.hfkj.service.goods.impl.GoodsSpecsServiceImpl;
import com.hfkj.service.hlt.HuiLianTongUnionCardService;
import com.hfkj.sysenum.GoodsVpdSourceEnum;
import com.hfkj.sysenum.order.OrderChildProductTypeEnum;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.stereotype.Component;

import javax.annotation.Resource;
import java.util.Date;
import java.util.List;

/**
 * @className: OrderPaySuccesService
 * @author: HuRui
 * @date: 2024/5/7
 **/
@Component
public class OrderPaySuccessService {
    Logger log = LoggerFactory.getLogger(OrderPaySuccessService.class);
    @Resource
    private BsOrderService orderService;
    @Resource
    private BsOrderGoodsService bsOrderGoodsService;
    @Resource
    private BsOrderCouponService orderCouponService;
    @Resource
    private BsOrderCouponNoService orderCouponNoService;
    @Resource
    private GoodsMsgService goodsMsgService;
    @Resource
    private GoodsVpdService goodsVpdService;
    private GoodsSpecsServiceImpl goodsSpecsService;

    /**
     * 订单业务处理
     * @param order
     * @throws Exception
     */
    public void orderBusHandle(OrderModel order) {
        for (BsOrderChild childOrder : order.getOrderChildList()) {
            try {
                if (childOrder.getProductType().equals(OrderChildProductTypeEnum.type1.getCode())) {
                    goods(order);
                } else if (childOrder.getProductType().equals(OrderChildProductTypeEnum.type2.getCode())) {
                    product(order, childOrder);
                }
             } catch (Exception e) {

            }
        }
    }

    /**
     * 处理产品
     * @param childOrder
     * @throws Exception
     */
    public void product(OrderModel order,BsOrderChild childOrder) throws Exception {
        // 查询产品
        GoodsMsg goods = goodsMsgService.queryDetail(childOrder.getProductId());
        if (goods.getType() == 1) {

        } else if (goods.getType() == 2) {
            productVpd(order, childOrder);
        }
    }

    /**
     * 虚拟产品
     * @param childOrder
     */
    public void productVpd(OrderModel order, BsOrderChild childOrder) throws Exception {
        // 查询卡券订单
        BsOrderCoupon orderCoupon = orderCouponService.getDetailByChildOrderNo(childOrder.getChildOrderNo());
        // 查询卡券订单的卡密
        List<BsOrderCouponNo> couponNoList = orderCouponNoService.getListByCouponOrderId(orderCoupon.getId());
        for (BsOrderCouponNo couponNo : couponNoList) {
            try {
                // 虚拟商品
                GoodsVpd vpd = goodsVpdService.queryDetail(childOrder.getProductSpecId());
                if (vpd.getSource() == GoodsVpdSourceEnum.type1.getCode()) {

                } else if (vpd.getSource() == GoodsVpdSourceEnum.type4.getCode()) {
                    // 推送给汇联通
                    JSONObject returnParam = HuiLianTongCouponService.costRechargeOrder(couponNo.getChannelOrderNo());
                    if (returnParam.getString("respCode").equals("0000")) {
                        // 解密
                        JSONObject jsonObject = HuiLianTongUnionCardService.resolveResponse(returnParam.getString("data"));
                        JSONArray dataArray = JSONObject.parseObject(jsonObject.getString("data"), JSONArray.class);
                        for (Object data : dataArray) {
                            JSONObject dataObject = (JSONObject) data;
                            couponNo.setExpireTime(dataObject.getDate("validEndDate"));
                            couponNo.setGoodsVpdSourceCouNo(dataObject.getString("couNo"));
                            orderCouponNoService.editData(couponNo);
                        }
                    }

                } else if (vpd.getSource() == GoodsVpdSourceEnum.type5.getCode()) {
                    // 预发码
                    JSONObject preSendCoupon = ChongQingCNPCCouponService.preSendCoupon(orderCoupon.getGoodsVpdKey(), orderCoupon.getOrderNo(), 1, orderCoupon.getUserPhone());
                    if (preSendCoupon.getInteger("status").equals(1)) {
                        // 给用户发码
                        JSONObject response = ChongQingCNPCCouponService.sendCNPCTicket(orderCoupon.getGoodsVpdKey(), orderCoupon.getOrderNo(), 1, orderCoupon.getUserPhone());
                        JSONObject couponDetail = response.getJSONObject("ticketDetail");
                        JSONArray codeList = response.getJSONArray("codeList");
                        for (Object data : codeList) {
                            couponNo.setExpireTime(DateUtil.format(couponDetail.getString("expiredDate"), "yyyy-MM-dd"));
                            couponNo.setGoodsVpdSourceCouNo(ChongQingCNPCCouponService.decryptCouponCode(String.valueOf(data)));
                            orderCouponNoService.editData(couponNo);
                        }
                    }

                } else if (vpd.getSource() == GoodsVpdSourceEnum.type6.getCode()) {

                } else if (vpd.getSource() == GoodsVpdSourceEnum.type7.getCode()) {
                // 发放卡券
                JSONObject jsonObject = PetroConfig.getCoupon(orderCoupon.getGoodsVpdKey(), orderCoupon.getUserPhone());
                if (!jsonObject.getString("resultCode").equals("0000")) {
                    throw ErrorHelp.genException(SysCode.System , ErrorCode.COMMON_ERROR , jsonObject.getString("errMsg"));
                }
                String data = PetroConfig.decrypt(jsonObject.getString("jsonResult"));
                JSONObject object = JSONObject.parseObject(data);
                couponNo.setExpireTime(vpd.getSalesEndTime());
                couponNo.setGoodsVpdSourceCouNo(object.getString("voucher"));
                orderCouponService.editData(orderCoupon);

                } else if (vpd.getSource() == GoodsVpdSourceEnum.type10.getCode()) {
                    // 发放卡券
                    JSONObject jsonObject = PcytCNPCCouponConfig.getCoupon(orderCoupon.getOrderNo() , orderCoupon.getUserPhone() , orderCoupon.getGoodsVpdKey());
                    if (!jsonObject.getString("code").equals("200")) {
                        throw ErrorHelp.genException(SysCode.System , ErrorCode.COMMON_ERROR , jsonObject.getString("errMsg"));
                    }
                    JSONObject object = jsonObject.getJSONObject("data");
                    couponNo.setExpireTime(vpd.getSalesEndTime());
                    couponNo.setGoodsVpdSourceCouNo(object.getString("couponCode"));
                    orderCouponNoService.editData(couponNo);
                }


            } catch (Exception e) {
                couponNo.setExceptionStatus(true);
                orderCouponService.editData(orderCoupon);
            }
        }

        orderCoupon.setTotalPrice(childOrder.getProductTotalPrice());
        orderCoupon.setTotalDeductionPrice(childOrder.getTotalDeductionPrice());
        orderCoupon.setCouponDiscountPrice(childOrder.getCouponDiscountPrice());
        orderCoupon.setIntegralDiscountPrice(childOrder.getIntegralDiscountPrice());
        orderCoupon.setPayRealPrice(childOrder.getSurplusRefundPrice());
        orderCoupon.setPayChannel(order.getPayChannel());
        orderCoupon.setPayType(order.getPayType());
        orderCoupon.setPaySerialNo(order.getPaySerialNo());
        orderCouponService.editData(orderCoupon);

        // 增加销量
        goodsMsgService.editSaleNum(childOrder.getProductId(), childOrder.getProductCount(), 1);

        // 子订单完成
        orderService.childOrderComplete(orderCoupon.getChildOrderNo());
    }
    /**
     * 实物产品
     * @param order
     */
    public void goods(OrderModel order) throws Exception {
        BsOrderGoods goodsOrder = bsOrderGoodsService.findGoodsOrder(order.getOrderNo());

        if (goodsOrder == null) {
            throw ErrorHelp.genException(SysCode.System , ErrorCode.COMMON_ERROR , "未查询到相关内容");
        }

        goodsMsgService.editSaleNum(goodsOrder.getGoodsId() , goodsOrder.getGoodsCount() , 1);


        goodsOrder.setUpdateTime(new Date());
        goodsOrder.setStatus(1);
        bsOrderGoodsService.update(goodsOrder);
    }

}
